Package: gggda
Title: A 'ggplot2' Extension for Geometric Data Analysis
Version: 0.1.1
Authors@R: c(
  person("Jason Cory", "Brunson", email = "cornelioid@gmail.com",
    role = c("aut", "cre"), comment = c(ORCID = "0000-0003-3126-9494")),
  person("Emily", "Paul", email = "erpb.71@gmail.com",
    role = "ctb"),
  person("John", "Gracey", email = "jbgracey6@gmail.com",
    role = "aut")
  )
Description: A variety of multivariable data summary statistics and 
    constructions have been proposed, either to generalize univariable analogs 
    or to exploit multivariable properties.
    Notable among these are the bivariate peelings surveyed by Green 
    (1981, ISBN:978-0-471-28039-2),
    the bag-and-bolster plots proposed by Rousseeuw &al (1999) 
    <doi:10.1080/00031305.1999.10474494>, and the minimum spanning trees used by
    Jolliffe (2002) <doi:10.1007/b98835> to represent high-dimensional 
    relationships among data in a low-dimensional plot.
    Additionally, biplots of singular value--decomposed tabular data, such as
    from principal components analysis, make use of vectors, calibrated axes,
    and other representations of variable elements to complement point markers
    for case elements; see Gabriel (1971) <doi:10.1093/biomet/58.3.453> and
    Gower & Harding (1988) <doi:10.1093/biomet/75.3.445> for original proposals.
    Because they treat the abscissa and ordinate as commensurate or the data
    elements themselves as point masses or unit vectors, these multivariable
    tools can be thought of as belonging to geometric data analysis; see Podani
    (2000, ISBN:90-5782-067-6) for techniques and applications and Le Roux &
    Rouanet (2005) <doi:10.1007/1-4020-2236-0> for foundations. 'gggda' extends
    Wickham's (2010) <doi:10.1198/jcgs.2009.07098> layered grammar of graphics
    with statistical transformation ("stat") and geometric construction ("geom")
    layers for many of these tools, as well as convenience coordinate systems
    to emphasize intrinsic geometry of the data.
Depends: R (>= 3.3.0), ggplot2
Imports: rlang, tidyr, dplyr, magrittr, scales, labeling, ddalpha
Suggests: gridExtra, MASS, Hmisc, tibble, mlpack, testthat, knitr,
        rmarkdown
License: GPL-3
Encoding: UTF-8
URL: https://github.com/corybrunson/gggda,
        https://corybrunson.github.io/gggda/
BugReports: https://github.com/corybrunson/gggda/issues
RoxygenNote: 7.3.2
Collate: 'aaa-.r' 'aes-coord.r' 'coord-rect.r' 'depth-median.r'
        'geom-axis.r' 'geom-bagplot.r' 'key-intervals.r'
        'geom-intervals.r' 'geom-isoline.r' 'geom-rule.r'
        'geom-text-radiate.r' 'geom-utils.r' 'geom-vector.r' 'gggda.r'
        'peel.r' 'stat-peel.r' 'stat-depth.r' 'stat-bagplot.r'
        'stat-center.r' 'stat-cone.r' 'stat-referent.r' 'stat-rule.r'
        'stat-scale.r' 'stat-spantree.r' 'utils.r'
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-07-18 23:29:34 UTC; jasoncorybrunson
Author: Jason Cory Brunson [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-3126-9494>),
  Emily Paul [ctb],
  John Gracey [aut]
Maintainer: Jason Cory Brunson <cornelioid@gmail.com>
Repository: CRAN
Date/Publication: 2025-07-19 23:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 18:38:34 UTC; unix
