# Generated by roxygen2: do not edit by hand

S3method(ggplot_add,LayerRef)
export("%>%")
export(CoordRect)
export(GeomAxis)
export(GeomBagplot)
export(GeomIsoline)
export(GeomLineranges)
export(GeomPointranges)
export(GeomRule)
export(GeomTextRadiate)
export(GeomVector)
export(StatBagplot)
export(StatCenter)
export(StatChull)
export(StatCone)
export(StatDepth)
export(StatDepthFilled)
export(StatPeel)
export(StatReferent)
export(StatRule)
export(StatScale)
export(StatSpantree)
export(StatStar)
export(aes_c)
export(aes_coord)
export(coord_rect)
export(coord_square)
export(depth_median)
export(draw_key_crosslines)
export(draw_key_crosspoint)
export(draw_key_line)
export(geom_axis)
export(geom_bagplot)
export(geom_isoline)
export(geom_lineranges)
export(geom_pointranges)
export(geom_rule)
export(geom_text_radiate)
export(geom_vector)
export(get_aes_coord)
export(is.sync)
export(maxpp)
export(minabspp)
export(minpp)
export(peel_hulls)
export(stat_bagplot)
export(stat_center)
export(stat_chull)
export(stat_cone)
export(stat_depth)
export(stat_depth_filled)
export(stat_peel)
export(stat_referent)
export(stat_rule)
export(stat_scale)
export(stat_spantree)
export(stat_star)
export(sync)
import(ggplot2)
importFrom(dplyr,bind_rows)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,transmute)
importFrom(dplyr,ungroup)
importFrom(grDevices,chull)
importFrom(magrittr,"%>%")
importFrom(rlang,"%||%")
importFrom(scales,censor)
importFrom(scales,expand_range)
importFrom(scales,rescale)
importFrom(tidyr,nest)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,unnest)
